nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Misc1

Struct Misc1 

#[repr(transparent)]
pub struct Misc1(pub u32);
Miscellaneous Register 1

Tuple Fields

0: u32

Implementations

Source

impl Misc1

pub const fn pfd_480_autogate_en(&self) -> bool

This enables a feature that will clkgate (reset) all PFD_480 clocks anytime the USB1_PLL_480 is unlocked or powered off

pub const fn set_pfd_480_autogate_en(&mut self, val: bool)

This enables a feature that will clkgate (reset) all PFD_480 clocks anytime the USB1_PLL_480 is unlocked or powered off

pub const fn pfd_528_autogate_en(&self) -> bool

This enables a feature that will clkgate (reset) all PFD_528 clocks anytime the PLL_528 is unlocked or powered off

pub const fn set_pfd_528_autogate_en(&mut self, val: bool)

This enables a feature that will clkgate (reset) all PFD_528 clocks anytime the PLL_528 is unlocked or powered off

pub const fn irq_temppanic(&self) -> bool

This status bit is set to one when the temperature sensor panic interrupt asserts for a panic high temperature

pub const fn set_irq_temppanic(&mut self, val: bool)

This status bit is set to one when the temperature sensor panic interrupt asserts for a panic high temperature

pub const fn irq_templow(&self) -> bool

This status bit is set to one when the temperature sensor low interrupt asserts for low temperature

pub const fn set_irq_templow(&mut self, val: bool)

This status bit is set to one when the temperature sensor low interrupt asserts for low temperature

pub const fn irq_temphigh(&self) -> bool

This status bit is set to one when the temperature sensor high interrupt asserts for high temperature

pub const fn set_irq_temphigh(&mut self, val: bool)

This status bit is set to one when the temperature sensor high interrupt asserts for high temperature

pub const fn irq_ana_bo(&self) -> bool

This status bit is set to one when when any of the analog regulator brownout interrupts assert

pub const fn set_irq_ana_bo(&mut self, val: bool)

This status bit is set to one when when any of the analog regulator brownout interrupts assert

pub const fn irq_dig_bo(&self) -> bool

This status bit is set to one when when any of the digital regulator brownout interrupts assert

pub const fn set_irq_dig_bo(&mut self, val: bool)

This status bit is set to one when when any of the digital regulator brownout interrupts assert