#[repr(transparent)]pub struct Reg2p5Set(pub u32);Expand description
Regulator 2P5 Register
Tuple Fields
0: u32Implementations
Sourceimpl Reg2p5Set
impl Reg2p5Set
Sourcepub const fn enable_linreg(&self) -> bool
pub const fn enable_linreg(&self) -> bool
Control bit to enable the regulator output.
Sourcepub const fn set_enable_linreg(&mut self, val: bool)
pub const fn set_enable_linreg(&mut self, val: bool)
Control bit to enable the regulator output.
Sourcepub const fn enable_bo(&self) -> bool
pub const fn enable_bo(&self) -> bool
Control bit to enable the brownout circuitry in the regulator.
Sourcepub const fn set_enable_bo(&mut self, val: bool)
pub const fn set_enable_bo(&mut self, val: bool)
Control bit to enable the brownout circuitry in the regulator.
Sourcepub const fn enable_ilimit(&self) -> bool
pub const fn enable_ilimit(&self) -> bool
Control bit to enable the current-limit circuitry in the regulator.
Sourcepub const fn set_enable_ilimit(&mut self, val: bool)
pub const fn set_enable_ilimit(&mut self, val: bool)
Control bit to enable the current-limit circuitry in the regulator.
Sourcepub const fn enable_pulldown(&self) -> bool
pub const fn enable_pulldown(&self) -> bool
Control bit to enable the pull-down circuitry in the regulator
Sourcepub const fn set_enable_pulldown(&mut self, val: bool)
pub const fn set_enable_pulldown(&mut self, val: bool)
Control bit to enable the pull-down circuitry in the regulator
Sourcepub const fn bo_offset(&self) -> u8
pub const fn bo_offset(&self) -> u8
Control bits to adjust the regulator brownout offset voltage in 25mV steps
Sourcepub const fn set_bo_offset(&mut self, val: u8)
pub const fn set_bo_offset(&mut self, val: u8)
Control bits to adjust the regulator brownout offset voltage in 25mV steps
Sourcepub const fn output_trg(&self) -> Reg2p5SetOutputTrg
pub const fn output_trg(&self) -> Reg2p5SetOutputTrg
Control bits to adjust the regulator output voltage
Sourcepub const fn set_output_trg(&mut self, val: Reg2p5SetOutputTrg)
pub const fn set_output_trg(&mut self, val: Reg2p5SetOutputTrg)
Control bits to adjust the regulator output voltage
Sourcepub const fn bo_vdd2p5(&self) -> bool
pub const fn bo_vdd2p5(&self) -> bool
Status bit that signals when a brownout is detected on the regulator output.
Sourcepub const fn set_bo_vdd2p5(&mut self, val: bool)
pub const fn set_bo_vdd2p5(&mut self, val: bool)
Status bit that signals when a brownout is detected on the regulator output.
Sourcepub const fn ok_vdd2p5(&self) -> bool
pub const fn ok_vdd2p5(&self) -> bool
Status bit that signals when the regulator output is ok. 1 = regulator output > brownout target
Sourcepub const fn set_ok_vdd2p5(&mut self, val: bool)
pub const fn set_ok_vdd2p5(&mut self, val: bool)
Status bit that signals when the regulator output is ok. 1 = regulator output > brownout target
Sourcepub const fn enable_weak_linreg(&self) -> bool
pub const fn enable_weak_linreg(&self) -> bool
Enables the weak 2p5 regulator
Sourcepub const fn set_enable_weak_linreg(&mut self, val: bool)
pub const fn set_enable_weak_linreg(&mut self, val: bool)
Enables the weak 2p5 regulator