nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Reg3p0Set

Struct Reg3p0Set 

#[repr(transparent)]
pub struct Reg3p0Set(pub u32);
Regulator 3P0 Register

Tuple Fields

0: u32

Implementations

Source

impl Reg3p0Set

pub const fn enable_linreg(&self) -> bool

Control bit to enable the regulator output to be set by the programmed target voltage setting and internal bandgap reference

pub const fn set_enable_linreg(&mut self, val: bool)

Control bit to enable the regulator output to be set by the programmed target voltage setting and internal bandgap reference

pub const fn enable_bo(&self) -> bool

Control bit to enable the brownout circuitry in the regulator.

pub const fn set_enable_bo(&mut self, val: bool)

Control bit to enable the brownout circuitry in the regulator.

pub const fn enable_ilimit(&self) -> bool

Control bit to enable the current-limit circuitry in the regulator.

pub const fn set_enable_ilimit(&mut self, val: bool)

Control bit to enable the current-limit circuitry in the regulator.

pub const fn bo_offset(&self) -> u8

Control bits to adjust the regulator brownout offset voltage in 25mV steps

pub const fn set_bo_offset(&mut self, val: u8)

Control bits to adjust the regulator brownout offset voltage in 25mV steps

pub const fn vbus_sel(&self) -> Reg3p0SetVbusSel

Select input voltage source for LDO_3P0 from either USB_OTG1_VBUS or USB_OTG2_VBUS

pub const fn set_vbus_sel(&mut self, val: Reg3p0SetVbusSel)

Select input voltage source for LDO_3P0 from either USB_OTG1_VBUS or USB_OTG2_VBUS

pub const fn output_trg(&self) -> Reg3p0SetOutputTrg

Control bits to adjust the regulator output voltage

pub const fn set_output_trg(&mut self, val: Reg3p0SetOutputTrg)

Control bits to adjust the regulator output voltage

pub const fn bo_vdd3p0(&self) -> bool

Status bit that signals when a brownout is detected on the regulator output.

pub const fn set_bo_vdd3p0(&mut self, val: bool)

Status bit that signals when a brownout is detected on the regulator output.

pub const fn ok_vdd3p0(&self) -> bool

Status bit that signals when the regulator output is ok. 1 = regulator output > brownout target

pub const fn set_ok_vdd3p0(&mut self, val: bool)

Status bit that signals when the regulator output is ok. 1 = regulator output > brownout target