nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

RegCoreClr

Struct RegCoreClr 

#[repr(transparent)]
pub struct RegCoreClr(pub u32);
Digital Regulator Core Register

Tuple Fields

0: u32

Implementations

Source

impl RegCoreClr

pub const fn reg0_targ(&self) -> RegCoreClrReg0Targ

This field defines the target voltage for the Arm core power domain

pub const fn set_reg0_targ(&mut self, val: RegCoreClrReg0Targ)

This field defines the target voltage for the Arm core power domain

pub const fn reg0_adj(&self) -> RegCoreClrReg0Adj

This bit field defines the adjustment bits to calibrate the target value of Reg0. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.

pub const fn set_reg0_adj(&mut self, val: RegCoreClrReg0Adj)

This bit field defines the adjustment bits to calibrate the target value of Reg0. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.

pub const fn reg1_targ(&self) -> RegCoreClrReg1Targ

This bit field defines the target voltage for the vpu/gpu power domain. Single bit increments reflect 25mV core voltage steps. Not all steps will make sense to use either because of input supply limitations or load operation.

pub const fn set_reg1_targ(&mut self, val: RegCoreClrReg1Targ)

This bit field defines the target voltage for the vpu/gpu power domain. Single bit increments reflect 25mV core voltage steps. Not all steps will make sense to use either because of input supply limitations or load operation.

pub const fn reg1_adj(&self) -> RegCoreClrReg1Adj

This bit field defines the adjustment bits to calibrate the target value of Reg1. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.

pub const fn set_reg1_adj(&mut self, val: RegCoreClrReg1Adj)

This bit field defines the adjustment bits to calibrate the target value of Reg1. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.

pub const fn reg2_targ(&self) -> RegCoreClrReg2Targ

This field defines the target voltage for the SOC power domain

pub const fn set_reg2_targ(&mut self, val: RegCoreClrReg2Targ)

This field defines the target voltage for the SOC power domain

pub const fn reg2_adj(&self) -> RegCoreClrReg2Adj

This bit field defines the adjustment bits to calibrate the target value of Reg2. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.

pub const fn set_reg2_adj(&mut self, val: RegCoreClrReg2Adj)

This bit field defines the adjustment bits to calibrate the target value of Reg2. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.

pub const fn ramp_rate(&self) -> RegCoreClrRampRate

Regulator voltage ramp rate.

pub const fn set_ramp_rate(&mut self, val: RegCoreClrRampRate)

Regulator voltage ramp rate.

pub const fn fet_odrive(&self) -> bool

If set, increases the gate drive on power gating FETs to reduce leakage in the off state

pub const fn set_fet_odrive(&mut self, val: bool)

If set, increases the gate drive on power gating FETs to reduce leakage in the off state